@@ -140,6 +140,28 @@ bfd_simple_get_relocated_section_contents (bfd *abfd,
   bfd_byte *contents, *data;
   int storage_needed;
   void *saved_offsets;
+  bfd_boolean saved_reloc_done = sec->reloc_done;
+
+#undef RETURN
+#define RETURN(x)				\
+  do						\
+    {						\
+      sec->reloc_done = saved_reloc_done;	\
+      return (x);				\
+    }						\
+  while (0)
+
+  /* Foul hack to prevent bfd_section_size aborts.  The reloc_done flag
+     only controls that macro (and the related size macros), selecting
+     between _raw_size and _cooked_size.  We may be called with relocation
+     done or not, so we need to save the done-flag and mark the section as
+     not relocated.
+
+     Debug sections won't change size while we're only relocating.  There
+     may be trouble here someday if it tries to run relaxation
+     unexpectedly, so make sure.  */
+  BFD_ASSERT (sec->_raw_size == sec->_cooked_size);
+  sec->reloc_done = 0;
 
   if (! (sec->flags & SEC_RELOC))
     {
@@ -153,7 +175,7 @@ bfd_simple_get_relocated_section_contents (bfd *abfd,
       if (contents)
 	bfd_get_section_contents (abfd, sec, contents, 0, size);
 
-      return contents;
+      RETURN (contents);
     }
 
   /* In order to use bfd_get_relocated_section_contents, we need
@@ -163,7 +185,7 @@ bfd_simple_get_relocated_section_contents (bfd *abfd,
   memset (&link_info, 0, sizeof (link_info));
   link_info.input_bfds = abfd;
 
-  link_info.hash = bfd_link_hash_table_create (abfd);
+  link_info.hash = _bfd_generic_link_hash_table_create (abfd);
   link_info.callbacks = &callbacks;
   callbacks.warning = simple_dummy_warning;
   callbacks.undefined_symbol = simple_dummy_undefined_symbol;
@@ -183,13 +205,13 @@ bfd_simple_get_relocated_section_contents (bfd *abfd,
     {
       data = bfd_malloc (bfd_section_size (abfd, sec));
       if (data == NULL)
-	return NULL;
+	RETURN (NULL);
       outbuf = data;
     }
 
   /* The sections in ABFD may already have output sections and offsets set.
      Because this function is primarily for debug sections, and GCC uses the
-     knowledge that debug sections will generally have VMA 0 when emiting
+     knowledge that debug sections will generally have VMA 0 when emitting
      relocations between DWARF-2 sections (which are supposed to be
      section-relative offsets anyway), we need to reset the output offsets
      to zero.  We also need to arrange for section->output_section->vma plus
@@ -202,7 +224,7 @@ bfd_simple_get_relocated_section_contents (bfd *abfd,
     {
       if (data)
 	free (data);
-      return NULL;
+      RETURN (NULL);
     }
   bfd_map_over_sections (abfd, simple_save_output_info, saved_offsets);
 
@@ -243,15 +265,7 @@ bfd_simple_get_relocated_section_contents (bfd *abfd,
   bfd_map_over_sections (abfd, simple_restore_output_info, saved_offsets);
   free (saved_offsets);
 
-  /* Foul hack to prevent bfd_section_size aborts.  This flag only controls
-     that macro (and the related size macros), selecting between _raw_size
-     and _cooked_size.  Debug sections won't change size while we're only
-     relocating.  There may be trouble here someday if it tries to run
-     relaxation unexpectedly, so make sure.  */
-  BFD_ASSERT (sec->_raw_size == sec->_cooked_size);
-  sec->reloc_done = 0;
+  _bfd_generic_link_hash_table_free (link_info.hash);
 
-  bfd_link_hash_table_free (abfd, link_info.hash);
-
-  return contents;
+  RETURN (contents);
 }
