@@ -53,45 +53,25 @@
 #include "elf/i370.h"
 #endif
 
-static bfd_vma elf_s_get_size PARAMS ((symbolS *));
-static void elf_s_set_size PARAMS ((symbolS *, bfd_vma));
-static bfd_vma elf_s_get_align PARAMS ((symbolS *));
-static void elf_s_set_align PARAMS ((symbolS *, bfd_vma));
-static void elf_s_set_other PARAMS ((symbolS *, int));
-static int elf_sec_sym_ok_for_reloc PARAMS ((asection *));
-static void adjust_stab_sections PARAMS ((bfd *, asection *, PTR));
-static void build_group_lists PARAMS ((bfd *, asection *, PTR));
-static int elf_separate_stab_sections PARAMS ((void));
-static void elf_init_stab_section PARAMS ((segT));
-static symbolS *elf_common PARAMS ((int));
-
-#ifdef NEED_ECOFF_DEBUG
-static bfd_boolean elf_get_extr PARAMS ((asymbol *, EXTR *));
-static void elf_set_index PARAMS ((asymbol *, bfd_size_type));
-#endif
-
-static void obj_elf_line PARAMS ((int));
-void obj_elf_version PARAMS ((int));
-static void obj_elf_size PARAMS ((int));
-static void obj_elf_type PARAMS ((int));
-static void obj_elf_ident PARAMS ((int));
-static void obj_elf_weak PARAMS ((int));
-static void obj_elf_local PARAMS ((int));
-static void obj_elf_visibility PARAMS ((int));
-static int obj_elf_parse_section_letters PARAMS ((char *, size_t));
-static int obj_elf_section_word PARAMS ((char *, size_t));
-static char *obj_elf_section_name PARAMS ((void));
-static int obj_elf_section_type PARAMS ((char *, size_t));
-static void obj_elf_symver PARAMS ((int));
-static void obj_elf_subsection PARAMS ((int));
-static void obj_elf_popsection PARAMS ((int));
-static void obj_elf_tls_common PARAMS ((int));
+static void obj_elf_line (int);
+static void obj_elf_size (int);
+static void obj_elf_type (int);
+static void obj_elf_ident (int);
+static void obj_elf_weak (int);
+static void obj_elf_local (int);
+static void obj_elf_visibility (int);
+static void obj_elf_symver (int);
+static void obj_elf_subsection (int);
+static void obj_elf_popsection (int);
+static void obj_elf_tls_common (int);
+static void obj_elf_lcomm (int);
 
 static const pseudo_typeS elf_pseudo_table[] =
 {
   {"comm", obj_elf_common, 0},
   {"common", obj_elf_common, 1},
   {"ident", obj_elf_ident, 0},
+  {"lcomm", obj_elf_lcomm, 0},
   {"local", obj_elf_local, 0},
   {"previous", obj_elf_previous, 0},
   {"section", obj_elf_section, 0},
@@ -120,15 +100,15 @@ static const pseudo_typeS elf_pseudo_table[] =
   {"subsection", obj_elf_subsection, 0},
 
   /* These are GNU extensions to aid in garbage collecting C++ vtables.  */
-  {"vtable_inherit", (void (*) PARAMS ((int))) &obj_elf_vtable_inherit, 0},
-  {"vtable_entry", (void (*) PARAMS ((int))) &obj_elf_vtable_entry, 0},
+  {"vtable_inherit", (void (*) (int)) &obj_elf_vtable_inherit, 0},
+  {"vtable_entry", (void (*) (int)) &obj_elf_vtable_entry, 0},
 
   /* These are used for dwarf.  */
   {"2byte", cons, 2},
   {"4byte", cons, 4},
   {"8byte", cons, 8},
   /* These are used for dwarf2.  */
-  { "file", (void (*) PARAMS ((int))) dwarf2_directive_file, 0 },
+  { "file", (void (*) (int)) dwarf2_directive_file, 0 },
   { "loc",  dwarf2_directive_loc,  0 },
 
   /* We need to trap the section changing calls to handle .previous.  */
@@ -192,19 +172,21 @@ static const pseudo_typeS ecoff_debug_pseudo_table[] =
 /* This is called when the assembler starts.  */
 
 void
-elf_begin ()
+elf_begin (void)
 {
+  asection *s;
+
   /* Add symbols for the known sections to the symbol table.  */
-  symbol_table_insert (section_symbol (bfd_get_section_by_name (stdoutput,
-								TEXT_SECTION_NAME)));
-  symbol_table_insert (section_symbol (bfd_get_section_by_name (stdoutput,
-								DATA_SECTION_NAME)));
-  symbol_table_insert (section_symbol (bfd_get_section_by_name (stdoutput,
-								BSS_SECTION_NAME)));
+  s = bfd_get_section_by_name (stdoutput, TEXT_SECTION_NAME);
+  symbol_table_insert (section_symbol (s));
+  s = bfd_get_section_by_name (stdoutput, DATA_SECTION_NAME);
+  symbol_table_insert (section_symbol (s));
+  s = bfd_get_section_by_name (stdoutput, BSS_SECTION_NAME);
+  symbol_table_insert (section_symbol (s));
 }
 
 void
-elf_pop_insert ()
+elf_pop_insert (void)
 {
   pop_insert (elf_pseudo_table);
   if (ECOFF_DEBUGGING)
@@ -212,64 +194,53 @@ elf_pop_insert ()
 }
 
 static bfd_vma
-elf_s_get_size (sym)
-     symbolS *sym;
+elf_s_get_size (symbolS *sym)
 {
   return S_GET_SIZE (sym);
 }
 
 static void
-elf_s_set_size (sym, sz)
-     symbolS *sym;
-     bfd_vma sz;
+elf_s_set_size (symbolS *sym, bfd_vma sz)
 {
   S_SET_SIZE (sym, sz);
 }
 
 static bfd_vma
-elf_s_get_align (sym)
-     symbolS *sym;
+elf_s_get_align (symbolS *sym)
 {
   return S_GET_ALIGN (sym);
 }
 
 static void
-elf_s_set_align (sym, align)
-     symbolS *sym;
-     bfd_vma align;
+elf_s_set_align (symbolS *sym, bfd_vma align)
 {
   S_SET_ALIGN (sym, align);
 }
 
 int
-elf_s_get_other (sym)
-     symbolS *sym;
+elf_s_get_other (symbolS *sym)
 {
   return elf_symbol (symbol_get_bfdsym (sym))->internal_elf_sym.st_other;
 }
 
 static void
-elf_s_set_other (sym, other)
-     symbolS *sym;
-     int other;
+elf_s_set_other (symbolS *sym, int other)
 {
   S_SET_OTHER (sym, other);
 }
 
 static int
-elf_sec_sym_ok_for_reloc (sec)
-     asection *sec;
+elf_sec_sym_ok_for_reloc (asection *sec)
 {
   return obj_sec_sym_ok_for_reloc (sec);
 }
 
 void
-elf_file_symbol (s)
-     const char *s;
+elf_file_symbol (const char *s)
 {
   symbolS *sym;
 
-  sym = symbol_new (s, absolute_section, (valueT) 0, (struct frag *) 0);
+  sym = symbol_new (s, absolute_section, 0, NULL);
   symbol_set_frag (sym, &zero_address_frag);
   symbol_get_bfdsym (sym)->flags |= BSF_FILE;
 
@@ -287,193 +258,110 @@ elf_file_symbol (s)
 #endif
 }
 
+/* Called from read.c:s_comm after we've parsed .comm symbol, size.
+   Parse a possible alignment value.  */
+
 static symbolS *
-elf_common (is_common)
-     int is_common;
+elf_common_parse (int ignore ATTRIBUTE_UNUSED, symbolS *symbolP, addressT size)
 {
-  char *name;
-  char c;
-  char *p;
-  offsetT temp, size, sign;
-  symbolS *symbolP;
-  int have_align;
-  expressionS exp;
+  addressT align = 0;
+  int is_local = symbol_get_obj (symbolP)->local;
 
-  if (flag_mri && is_common)
+  if (*input_line_pointer == ',')
     {
-      s_mri_common (0);
-      return NULL;
-    }
+      char *save = input_line_pointer;
 
-  name = input_line_pointer;
-  c = get_symbol_end ();
-  /* just after name is now '\0' */
-  p = input_line_pointer;
-  *p = c;
-  SKIP_WHITESPACE ();
-  if (*input_line_pointer != ',')
-    {
-      as_bad (_("expected comma after symbol-name"));
-      ignore_rest_of_line ();
-      return NULL;
-    }
-  input_line_pointer++;		/* skip ',' */
-  temp = get_absolute_expr (&exp);
-  sign = (offsetT) 1 << (stdoutput->arch_info->bits_per_address - 1);
-  size = temp & ((sign << 1) - 1);
-  if (temp != size || !exp.X_unsigned)
-    {
-      as_bad (_(".COMMon length (%ld) out of range, ignored."), (long) temp);
-      ignore_rest_of_line ();
-      return NULL;
-    }
-  *p = 0;
-  symbolP = symbol_find_or_make (name);
-  *p = c;
-  if (S_IS_DEFINED (symbolP) && ! S_IS_COMMON (symbolP))
-    {
-      as_bad (_("symbol `%s' is already defined"), S_GET_NAME (symbolP));
-      ignore_rest_of_line ();
-      return NULL;
-    }
-  if (S_GET_VALUE (symbolP) != 0)
-    {
-      if (S_GET_VALUE (symbolP) != (valueT) size)
-	{
-	  as_warn (_("length of .comm \"%s\" is already %ld; not changed to %ld"),
-		   S_GET_NAME (symbolP), (long) S_GET_VALUE (symbolP),
-		   (long) size);
-	}
-    }
-  know (symbolP->sy_frag == &zero_address_frag);
-  if (*input_line_pointer != ',')
-    have_align = 0;
-  else
-    {
-      have_align = 1;
       input_line_pointer++;
       SKIP_WHITESPACE ();
-    }
-  if (! have_align || *input_line_pointer != '"')
-    {
-      if (! have_align)
-	temp = 0;
-      else
-	{
-	  temp = get_absolute_expr (&exp);
-	  if (!exp.X_unsigned)
-	    {
-	      temp = 0;
-	      as_warn (_("common alignment negative; 0 assumed"));
-	    }
-	}
-      if (symbol_get_obj (symbolP)->local)
-	{
-	  segT old_sec;
-	  int old_subsec;
-	  char *pfrag;
-	  int align;
 
-	/* allocate_bss: */
-	  old_sec = now_seg;
-	  old_subsec = now_subseg;
-	  if (temp)
-	    {
-	      /* convert to a power of 2 alignment */
-	      for (align = 0; (temp & 1) == 0; temp >>= 1, ++align);
-	      if (temp != 1)
-		{
-		  as_bad (_("common alignment not a power of 2"));
-		  ignore_rest_of_line ();
-		  return NULL;
-		}
-	    }
+      if (*input_line_pointer == '"')
+	{
+	  /* For sparc.  Accept .common symbol, length, "bss"  */
+	  input_line_pointer++;
+	  /* Some use the dot, some don't.  */
+	  if (*input_line_pointer == '.')
+	    input_line_pointer++;
+	  /* Some say data, some say bss.  */
+	  if (strncmp (input_line_pointer, "bss\"", 4) == 0)
+	    input_line_pointer += 4;
+	  else if (strncmp (input_line_pointer, "data\"", 5) == 0)
+	    input_line_pointer += 5;
 	  else
-	    align = 0;
-	  record_alignment (bss_section, align);
-	  subseg_set (bss_section, 0);
-	  if (align)
-	    frag_align (align, 0, 0);
-	  if (S_GET_SEGMENT (symbolP) == bss_section)
-	    symbol_get_frag (symbolP)->fr_symbol = 0;
-	  symbol_set_frag (symbolP, frag_now);
-	  pfrag = frag_var (rs_org, 1, 1, (relax_substateT) 0, symbolP,
-			    (offsetT) size, (char *) 0);
-	  *pfrag = 0;
-	  S_SET_SIZE (symbolP, size);
-	  S_SET_SEGMENT (symbolP, bss_section);
-	  S_CLEAR_EXTERNAL (symbolP);
-	  subseg_set (old_sec, old_subsec);
+	    {
+	      char *p = input_line_pointer;
+	      char c;
+
+	      while (*--p != '"')
+		;
+	      while (!is_end_of_line[(unsigned char) *input_line_pointer])
+		if (*input_line_pointer++ == '"')
+		  break;
+	      c = *input_line_pointer;
+	      *input_line_pointer = '\0';
+	      as_bad (_("bad .common segment %s"), p);
+	      *input_line_pointer = c;
+	      ignore_rest_of_line ();
+	      return NULL;
+	    }
+	  /* ??? Don't ask me why these are always global.  */
+	  is_local = 0;
 	}
       else
 	{
-	allocate_common:
-	  S_SET_VALUE (symbolP, (valueT) size);
-	  S_SET_ALIGN (symbolP, temp);
-	  S_SET_EXTERNAL (symbolP);
-	  S_SET_SEGMENT (symbolP, bfd_com_section_ptr);
+	  input_line_pointer = save;
+	  align = parse_align (is_local);
+	  if (align == (addressT) -1)
+	    return NULL;
 	}
     }
+
+  if (is_local)
+    {
+      bss_alloc (symbolP, size, align);
+      S_CLEAR_EXTERNAL (symbolP);
+    }
   else
     {
-      input_line_pointer++;
-      /* @@ Some use the dot, some don't.  Can we get some consistency??  */
-      if (*input_line_pointer == '.')
-	input_line_pointer++;
-      /* @@ Some say data, some say bss.  */
-      if (strncmp (input_line_pointer, "bss\"", 4)
-	  && strncmp (input_line_pointer, "data\"", 5))
-	{
-	  while (*--input_line_pointer != '"')
-	    ;
-	  input_line_pointer--;
-	  goto bad_common_segment;
-	}
-      while (*input_line_pointer++ != '"')
-	;
-      goto allocate_common;
+      S_SET_VALUE (symbolP, size);
+      S_SET_ALIGN (symbolP, align);
+      S_SET_EXTERNAL (symbolP);
+      S_SET_SEGMENT (symbolP, bfd_com_section_ptr);
     }
 
   symbol_get_bfdsym (symbolP)->flags |= BSF_OBJECT;
 
-  demand_empty_rest_of_line ();
   return symbolP;
-
-  {
-  bad_common_segment:
-    p = input_line_pointer;
-    while (*p && *p != '\n')
-      p++;
-    c = *p;
-    *p = '\0';
-    as_bad (_("bad .common segment %s"), input_line_pointer + 1);
-    *p = c;
-    input_line_pointer = p;
-    ignore_rest_of_line ();
-    return NULL;
-  }
 }
 
 void
-obj_elf_common (is_common)
-     int is_common;
+obj_elf_common (int is_common)
 {
-  elf_common (is_common);
+  if (flag_mri && is_common)
+    s_mri_common (0);
+  else
+    s_comm_internal (0, elf_common_parse);
 }
 
 static void
-obj_elf_tls_common (ignore)
-     int ignore ATTRIBUTE_UNUSED;
+obj_elf_tls_common (int ignore ATTRIBUTE_UNUSED)
 {
-  symbolS *symbolP = elf_common (0);
+  symbolS *symbolP = s_comm_internal (0, elf_common_parse);
 
   if (symbolP)
     symbol_get_bfdsym (symbolP)->flags |= BSF_THREAD_LOCAL;
 }
 
 static void
-obj_elf_local (ignore)
-     int ignore ATTRIBUTE_UNUSED;
+obj_elf_lcomm (int ignore ATTRIBUTE_UNUSED)
+{
+  symbolS *symbolP = s_comm_internal (0, s_lcomm_internal);
+
+  if (symbolP)
+    symbol_get_bfdsym (symbolP)->flags |= BSF_OBJECT;
+}
+
+static void
+obj_elf_local (int ignore ATTRIBUTE_UNUSED)
 {
   char *name;
   int c;
@@ -501,8 +389,7 @@ obj_elf_local (ignore)
 }
 
 static void
-obj_elf_weak (ignore)
-     int ignore ATTRIBUTE_UNUSED;
+obj_elf_weak (int ignore ATTRIBUTE_UNUSED)
 {
   char *name;
   int c;
@@ -530,8 +417,7 @@ obj_elf_weak (ignore)
 }
 
 static void
-obj_elf_visibility (visibility)
-     int visibility;
+obj_elf_visibility (int visibility)
 {
   char *name;
   int c;
@@ -602,14 +488,13 @@ static struct section_stack *section_stack;
    BFD doesn't really let us set the section type.  */
 
 void
-obj_elf_change_section (name, type, attr, entsize, group_name, linkonce, push)
-     const char *name;
-     int type;
-     int attr;
-     int entsize;
-     const char *group_name;
-     int linkonce;
-     int push;
+obj_elf_change_section (const char *name,
+			int type,
+			int attr,
+			int entsize,
+			const char *group_name,
+			int linkonce,
+			int push)
 {
   asection *old_sec;
   segT sec;
@@ -730,7 +615,7 @@ obj_elf_change_section (name, type, attr, entsize, group_name, linkonce, push)
 
       /* Prevent SEC_HAS_CONTENTS from being inadvertently set.  */
       if (type == SHT_NOBITS)
-        seg_info (sec)->bss = 1;
+	seg_info (sec)->bss = 1;
 
       if (linkonce)
 	flags |= SEC_LINK_ONCE | SEC_LINK_DUPLICATES_DISCARD;
@@ -744,7 +629,7 @@ obj_elf_change_section (name, type, attr, entsize, group_name, linkonce, push)
       if (secsym != NULL)
 	symbol_set_bfdsym (secsym, sec->symbol);
       else
-        symbol_table_insert (section_symbol (sec));
+	symbol_table_insert (section_symbol (sec));
     }
   else if (attr != 0)
     {
@@ -770,9 +655,7 @@ obj_elf_change_section (name, type, attr, entsize, group_name, linkonce, push)
 }
 
 static int
-obj_elf_parse_section_letters (str, len)
-     char *str;
-     size_t len;
+obj_elf_parse_section_letters (char *str, size_t len)
 {
   int attr = 0;
 
@@ -833,9 +716,7 @@ obj_elf_parse_section_letters (str, len)
 }
 
 static int
-obj_elf_section_word (str, len)
-     char *str;
-     size_t len;
+obj_elf_section_word (char *str, size_t len)
 {
   if (len == 5 && strncmp (str, "write", 5) == 0)
     return SHF_WRITE;
@@ -859,9 +740,7 @@ obj_elf_section_word (str, len)
 }
 
 static int
-obj_elf_section_type (str, len)
-     char *str;
-     size_t len;
+obj_elf_section_type (char *str, size_t len)
 {
   if (len == 8 && strncmp (str, "progbits", 8) == 0)
     return SHT_PROGBITS;
@@ -884,7 +763,7 @@ obj_elf_section_type (str, len)
 
 /* Get name of section.  */
 static char *
-obj_elf_section_name ()
+obj_elf_section_name (void)
 {
   char *name;
 
@@ -926,8 +805,7 @@ obj_elf_section_name ()
 }
 
 void
-obj_elf_section (push)
-     int push;
+obj_elf_section (int push)
 {
   char *name, *group_name, *beg;
   int type, attr, dummy;
@@ -1085,8 +963,7 @@ obj_elf_section (push)
 /* Change to the .data section.  */
 
 void
-obj_elf_data (i)
-     int i;
+obj_elf_data (int i)
 {
 #ifdef md_flush_pending_output
   md_flush_pending_output ();
@@ -1104,8 +981,7 @@ obj_elf_data (i)
 /* Change to the .text section.  */
 
 void
-obj_elf_text (i)
-     int i;
+obj_elf_text (int i)
 {
 #ifdef md_flush_pending_output
   md_flush_pending_output ();
@@ -1121,8 +997,7 @@ obj_elf_text (i)
 }
 
 static void
-obj_elf_subsection (ignore)
-     int ignore ATTRIBUTE_UNUSED;
+obj_elf_subsection (int ignore ATTRIBUTE_UNUSED)
 {
   register int temp;
 
@@ -1146,15 +1021,14 @@ obj_elf_subsection (ignore)
    sections.  */
 
 void
-obj_elf_section_change_hook ()
+obj_elf_section_change_hook (void)
 {
   previous_section = now_seg;
   previous_subsection = now_subseg;
 }
 
 void
-obj_elf_previous (ignore)
-     int ignore ATTRIBUTE_UNUSED;
+obj_elf_previous (int ignore ATTRIBUTE_UNUSED)
 {
   segT new_section;
   int new_subsection;
@@ -1181,8 +1055,7 @@ obj_elf_previous (ignore)
 }
 
 static void
-obj_elf_popsection (xxx)
-     int xxx ATTRIBUTE_UNUSED;
+obj_elf_popsection (int xxx ATTRIBUTE_UNUSED)
 {
   struct section_stack *top = section_stack;
 
@@ -1208,12 +1081,11 @@ obj_elf_popsection (xxx)
 }
 
 static void
-obj_elf_line (ignore)
-     int ignore ATTRIBUTE_UNUSED;
+obj_elf_line (int ignore ATTRIBUTE_UNUSED)
 {
   /* Assume delimiter is part of expression.  BSD4.2 as fails with
      delightful bug, so we are not being incompatible here.  */
-  new_logical_line ((char *) NULL, (int) (get_absolute_expression ()));
+  new_logical_line (NULL, get_absolute_expression ());
   demand_empty_rest_of_line ();
 }
 
@@ -1224,8 +1096,7 @@ obj_elf_line (ignore)
    with the same value as the symbol NAME.  */
 
 static void
-obj_elf_symver (ignore)
-     int ignore ATTRIBUTE_UNUSED;
+obj_elf_symver (int ignore ATTRIBUTE_UNUSED)
 {
   char *name;
   char c;
@@ -1295,8 +1166,7 @@ obj_elf_symver (ignore)
    syntax is ".vtable_inherit CHILDNAME, PARENTNAME".  */
 
 struct fix *
-obj_elf_vtable_inherit (ignore)
-     int ignore ATTRIBUTE_UNUSED;
+obj_elf_vtable_inherit (int ignore ATTRIBUTE_UNUSED)
 {
   char *cname, *pname;
   symbolS *csym, *psym;
@@ -1367,8 +1237,7 @@ obj_elf_vtable_inherit (ignore)
    ".vtable_entry tablename, offset".  */
 
 struct fix *
-obj_elf_vtable_entry (ignore)
-     int ignore ATTRIBUTE_UNUSED;
+obj_elf_vtable_entry (int ignore ATTRIBUTE_UNUSED)
 {
   char *name;
   symbolS *sym;
@@ -1404,7 +1273,7 @@ obj_elf_vtable_entry (ignore)
 }
 
 void
-elf_obj_read_begin_hook ()
+elf_obj_read_begin_hook (void)
 {
 #ifdef NEED_ECOFF_DEBUG
   if (ECOFF_DEBUGGING)
@@ -1413,8 +1282,7 @@ elf_obj_read_begin_hook ()
 }
 
 void
-elf_obj_symbol_new_hook (symbolP)
-     symbolS *symbolP;
+elf_obj_symbol_new_hook (symbolS *symbolP)
 {
   struct elf_obj_sy *sy_obj;
 
@@ -1433,16 +1301,14 @@ elf_obj_symbol_new_hook (symbolP)
    context.  */
 
 void
-elf_copy_symbol_attributes (dest, src)
-     symbolS *dest, *src;
+elf_copy_symbol_attributes (symbolS *dest, symbolS *src)
 {
   struct elf_obj_sy *srcelf = symbol_get_obj (src);
   struct elf_obj_sy *destelf = symbol_get_obj (dest);
   if (srcelf->size)
     {
       if (destelf->size == NULL)
-	destelf->size =
-	  (expressionS *) xmalloc (sizeof (expressionS));
+	destelf->size = xmalloc (sizeof (expressionS));
       *destelf->size = *srcelf->size;
     }
   else
@@ -1458,8 +1324,7 @@ elf_copy_symbol_attributes (dest, src)
 }
 
 void
-obj_elf_version (ignore)
-     int ignore ATTRIBUTE_UNUSED;
+obj_elf_version (int ignore ATTRIBUTE_UNUSED)
 {
   char *name;
   unsigned int c;
@@ -1468,7 +1333,7 @@ obj_elf_version (ignore)
   subsegT subseg = now_subseg;
   Elf_Internal_Note i_note;
   Elf_External_Note e_note;
-  asection *note_secp = (asection *) NULL;
+  asection *note_secp = NULL;
   int len;
 
   SKIP_WHITESPACE ();
@@ -1499,11 +1364,11 @@ obj_elf_version (ignore)
       i_note.descsz = 0;	/* no description */
       i_note.type = NT_VERSION;
       p = frag_more (sizeof (e_note.namesz));
-      md_number_to_chars (p, (valueT) i_note.namesz, sizeof (e_note.namesz));
+      md_number_to_chars (p, i_note.namesz, sizeof (e_note.namesz));
       p = frag_more (sizeof (e_note.descsz));
-      md_number_to_chars (p, (valueT) i_note.descsz, sizeof (e_note.descsz));
+      md_number_to_chars (p, i_note.descsz, sizeof (e_note.descsz));
       p = frag_more (sizeof (e_note.type));
-      md_number_to_chars (p, (valueT) i_note.type, sizeof (e_note.type));
+      md_number_to_chars (p, i_note.type, sizeof (e_note.type));
       p = frag_more (len + 1);
       strcpy (p, name);
 
@@ -1519,8 +1384,7 @@ obj_elf_version (ignore)
 }
 
 static void
-obj_elf_size (ignore)
-     int ignore ATTRIBUTE_UNUSED;
+obj_elf_size (int ignore ATTRIBUTE_UNUSED)
 {
   char *name = input_line_pointer;
   char c = get_symbol_end ();
@@ -1561,8 +1425,7 @@ obj_elf_size (ignore)
     }
   else
     {
-      symbol_get_obj (sym)->size =
-	(expressionS *) xmalloc (sizeof (expressionS));
+      symbol_get_obj (sym)->size = xmalloc (sizeof (expressionS));
       *symbol_get_obj (sym)->size = exp;
     }
   demand_empty_rest_of_line ();
@@ -1584,8 +1447,7 @@ obj_elf_size (ignore)
    */
 
 static void
-obj_elf_type (ignore)
-     int ignore ATTRIBUTE_UNUSED;
+obj_elf_type (int ignore ATTRIBUTE_UNUSED)
 {
   char *name;
   char c;
@@ -1645,8 +1507,7 @@ obj_elf_type (ignore)
 }
 
 static void
-obj_elf_ident (ignore)
-     int ignore ATTRIBUTE_UNUSED;
+obj_elf_ident (int ignore ATTRIBUTE_UNUSED)
 {
   static segT comment_section;
   segT old_section = now_seg;
@@ -1676,8 +1537,7 @@ obj_elf_ident (ignore)
 /* The first entry in a .stabs section is special.  */
 
 void
-obj_elf_init_stab_section (seg)
-     segT seg;
+obj_elf_init_stab_section (segT seg)
 {
   char *file;
   char *p;
@@ -1692,8 +1552,8 @@ obj_elf_init_stab_section (seg)
   p = frag_more (12);
   /* Zero it out.  */
   memset (p, 0, 12);
-  as_where (&file, (unsigned int *) NULL);
-  stabstr_name = (char *) xmalloc (strlen (segment_name (seg)) + 4);
+  as_where (&file, NULL);
+  stabstr_name = xmalloc (strlen (segment_name (seg)) + 4);
   strcpy (stabstr_name, segment_name (seg));
   strcat (stabstr_name, "str");
   stroff = get_stab_string_offset (file, stabstr_name);
@@ -1707,10 +1567,7 @@ obj_elf_init_stab_section (seg)
 /* Fill in the counts in the first entry in a .stabs section.  */
 
 static void
-adjust_stab_sections (abfd, sec, xxx)
-     bfd *abfd;
-     asection *sec;
-     PTR xxx ATTRIBUTE_UNUSED;
+adjust_stab_sections (bfd *abfd, asection *sec, void *xxx ATTRIBUTE_UNUSED)
 {
   char *name;
   asection *strsec;
@@ -1722,7 +1579,7 @@ adjust_stab_sections (abfd, sec, xxx)
   if (!strcmp ("str", sec->name + strlen (sec->name) - 3))
     return;
 
-  name = (char *) alloca (strlen (sec->name) + 4);
+  name = alloca (strlen (sec->name) + 4);
   strcpy (name, sec->name);
   strcat (name, "str");
   strsec = bfd_get_section_by_name (abfd, name);
@@ -1735,8 +1592,8 @@ adjust_stab_sections (abfd, sec, xxx)
   p = seg_info (sec)->stabu.p;
   assert (p != 0);
 
-  bfd_h_put_16 (abfd, (bfd_vma) nsyms, (bfd_byte *) p + 6);
-  bfd_h_put_32 (abfd, (bfd_vma) strsz, (bfd_byte *) p + 8);
+  bfd_h_put_16 (abfd, nsyms, p + 6);
+  bfd_h_put_32 (abfd, strsz, p + 8);
 }
 
 #ifdef NEED_ECOFF_DEBUG
@@ -1748,11 +1605,9 @@ adjust_stab_sections (abfd, sec, xxx)
    in the symbol.  */
 
 void
-elf_ecoff_set_ext (sym, ext)
-     symbolS *sym;
-     struct ecoff_extr *ext;
+elf_ecoff_set_ext (symbolS *sym, struct ecoff_extr *ext)
 {
-  symbol_get_bfdsym (sym)->udata.p = (PTR) ext;
+  symbol_get_bfdsym (sym)->udata.p = ext;
 }
 
 /* This function is called by bfd_ecoff_debug_externals.  It is
@@ -1760,9 +1615,7 @@ elf_ecoff_set_ext (sym, ext)
    whether the symbol should be used at all.  */
 
 static bfd_boolean
-elf_get_extr (sym, ext)
-     asymbol *sym;
-     EXTR *ext;
+elf_get_extr (asymbol *sym, EXTR *ext)
 {
   if (sym->udata.p == NULL)
     return FALSE;
@@ -1773,20 +1626,16 @@ elf_get_extr (sym, ext)
 /* This function is called by bfd_ecoff_debug_externals.  It has
    nothing to do for ELF.  */
 
-/*ARGSUSED*/
 static void
-elf_set_index (sym, indx)
-     asymbol *sym ATTRIBUTE_UNUSED;
-     bfd_size_type indx ATTRIBUTE_UNUSED;
+elf_set_index (asymbol *sym ATTRIBUTE_UNUSED,
+	       bfd_size_type indx ATTRIBUTE_UNUSED)
 {
 }
 
 #endif /* NEED_ECOFF_DEBUG */
 
 void
-elf_frob_symbol (symp, puntp)
-     symbolS *symp;
-     int *puntp;
+elf_frob_symbol (symbolS *symp, int *puntp)
 {
   struct elf_obj_sy *sy_obj;
 
@@ -1829,9 +1678,9 @@ elf_frob_symbol (symp, puntp)
 
       /* This symbol was given a new name with the .symver directive.
 
-         If this is an external reference, just rename the symbol to
-         include the version string.  This will make the relocs be
-         against the correct versioned symbol.
+	 If this is an external reference, just rename the symbol to
+	 include the version string.  This will make the relocs be
+	 against the correct versioned symbol.
 
 	 If this is a definition, add an alias.  FIXME: Using an alias
 	 will permit the debugging information to refer to the right
@@ -1841,8 +1690,8 @@ elf_frob_symbol (symp, puntp)
       if (! S_IS_DEFINED (symp))
 	{
 	  /* Verify that the name isn't using the @@ syntax--this is
-             reserved for definitions of the default version to link
-             against.  */
+	     reserved for definitions of the default version to link
+	     against.  */
 	  if (p[1] == ELF_VER_CHR)
 	    {
 	      as_bad (_("invalid attempt to declare external version name as default in symbol `%s'"),
@@ -1853,14 +1702,14 @@ elf_frob_symbol (symp, puntp)
 	}
       else
 	{
-	  if (p [1] == ELF_VER_CHR && p [2] == ELF_VER_CHR)
+	  if (p[1] == ELF_VER_CHR && p[2] == ELF_VER_CHR)
 	    {
 	      size_t l;
 
 	      /* The @@@ syntax is a special case. It renames the
 		 symbol name to versioned_name with one `@' removed.  */
 	      l = strlen (&p[3]) + 1;
-	      memmove (&p [2], &p[3], l);
+	      memmove (&p[2], &p[3], l);
 	      S_SET_NAME (symp, sy_obj->versioned_name);
 	    }
 	  else
@@ -1952,12 +1801,9 @@ struct group_list
    each list.  */
 
 static void
-build_group_lists (abfd, sec, inf)
-     bfd *abfd ATTRIBUTE_UNUSED;
-     asection *sec;
-     PTR inf;
+build_group_lists (bfd *abfd ATTRIBUTE_UNUSED, asection *sec, void *inf)
 {
-  struct group_list *list = (struct group_list *) inf;
+  struct group_list *list = inf;
   const char *group_name = elf_group_name (sec);
   unsigned int i;
 
@@ -1993,18 +1839,18 @@ build_group_lists (abfd, sec, inf)
 }
 
 void
-elf_frob_file ()
+elf_frob_file (void)
 {
   struct group_list list;
   unsigned int i;
 
-  bfd_map_over_sections (stdoutput, adjust_stab_sections, (PTR) 0);
+  bfd_map_over_sections (stdoutput, adjust_stab_sections, NULL);
 
   /* Go find section groups.  */
   list.num_group = 0;
   list.head = NULL;
   list.elt_count = NULL;
-  bfd_map_over_sections (stdoutput, build_group_lists, (PTR) &list);
+  bfd_map_over_sections (stdoutput, build_group_lists, &list);
 
   /* Make the SHT_GROUP sections that describe each section group.  We
      can't set up the section contents here yet, because elf section
@@ -2071,7 +1917,7 @@ elf_frob_file ()
 /* It removes any unneeded versioned symbols from the symbol table.  */
 
 void
-elf_frob_file_before_adjust ()
+elf_frob_file_before_adjust (void)
 {
   if (symbol_rootP)
     {
@@ -2091,10 +1937,10 @@ elf_frob_file_before_adjust ()
 		p = strchr (symbol_get_obj (symp)->versioned_name,
 			    ELF_VER_CHR);
 		know (p != NULL);
-		if (p [1] == ELF_VER_CHR && p [2] == ELF_VER_CHR)
+		if (p[1] == ELF_VER_CHR && p[2] == ELF_VER_CHR)
 		  {
 		    size_t l = strlen (&p[3]) + 1;
-		    memmove (&p [1], &p[3], l);
+		    memmove (&p[1], &p[3], l);
 		  }
 		if (symbol_used_p (symp) == 0
 		    && symbol_used_in_reloc_p (symp) == 0)
@@ -2118,7 +1964,7 @@ elf_frob_file_before_adjust ()
    have generated the relocation section.  */
 
 void
-elf_frob_file_after_relocs ()
+elf_frob_file_after_relocs (void)
 {
 #ifdef NEED_ECOFF_DEBUG
   if (ECOFF_DEBUGGING)
@@ -2131,7 +1977,7 @@ elf_frob_file_after_relocs ()
 
       debug_swap
 	= get_elf_backend_data (stdoutput)->elf_backend_ecoff_debug_swap;
-      know (debug_swap != (const struct ecoff_debug_swap *) NULL);
+      know (debug_swap != NULL);
       ecoff_build_debug (&debug.symbolic_header, &buf, debug_swap);
 
       /* Set up the pointers in debug.  */
@@ -2139,14 +1985,14 @@ elf_frob_file_after_relocs ()
     debug.ptr = (type) (buf + debug.symbolic_header.offset)
 
       SET (line, cbLineOffset, unsigned char *);
-      SET (external_dnr, cbDnOffset, PTR);
-      SET (external_pdr, cbPdOffset, PTR);
-      SET (external_sym, cbSymOffset, PTR);
-      SET (external_opt, cbOptOffset, PTR);
+      SET (external_dnr, cbDnOffset, void *);
+      SET (external_pdr, cbPdOffset, void *);
+      SET (external_sym, cbSymOffset, void *);
+      SET (external_opt, cbOptOffset, void *);
       SET (external_aux, cbAuxOffset, union aux_ext *);
       SET (ss, cbSsOffset, char *);
-      SET (external_fdr, cbFdOffset, PTR);
-      SET (external_rfd, cbRfdOffset, PTR);
+      SET (external_fdr, cbFdOffset, void *);
+      SET (external_rfd, cbRfdOffset, void *);
       /* ssext and external_ext are set up just below.  */
 
 #undef SET
@@ -2171,11 +2017,10 @@ elf_frob_file_after_relocs ()
       sec->_raw_size = bfd_ecoff_debug_size (stdoutput, &debug, debug_swap);
 
       /* Pass BUF to bfd_set_section_contents because this will
-         eventually become a call to fwrite, and ISO C prohibits
-         passing a NULL pointer to a stdio function even if the
-         pointer will not be used.  */
-      if (! bfd_set_section_contents (stdoutput, sec, (PTR) buf,
-				      (file_ptr) 0, (bfd_size_type) 0))
+	 eventually become a call to fwrite, and ISO C prohibits
+	 passing a NULL pointer to a stdio function even if the
+	 pointer will not be used.  */
+      if (! bfd_set_section_contents (stdoutput, sec, buf, 0, 0))
 	as_fatal (_("can't start writing .mdebug section: %s"),
 		  bfd_errmsg (bfd_get_error ()));
 
@@ -2192,7 +2037,7 @@ elf_frob_file_after_relocs ()
 
 #ifdef SCO_ELF
 
-/* Heavily plagarized from obj_elf_version.  The idea is to emit the
+/* Heavily plagiarized from obj_elf_version.  The idea is to emit the
    SCO specific identifier in the .notes section to satisfy the SCO
    linker.
 
@@ -2212,7 +2057,7 @@ elf_frob_file_after_relocs ()
    int_32 version = (major ver # << 16)  | version of tools ;
    int_32 source  = (tool_id << 16 ) | 1 ;
    int_32 info    = 0 ;    These are set by the SCO tools, but we
-                           don't know enough about the source
+			   don't know enough about the source
 			   environment to set them.  SCO ld currently
 			   ignores them, and recommends we set them
 			   to zero.  */
@@ -2221,7 +2066,7 @@ elf_frob_file_after_relocs ()
 #define SCO_MINOR_VERSION 0x1
 
 void
-sco_id ()
+sco_id (void)
 {
 
   char *name;
@@ -2232,7 +2077,7 @@ sco_id ()
   subsegT subseg = now_subseg;
   Elf_Internal_Note i_note;
   Elf_External_Note e_note;
-  asection *note_secp = (asection *) NULL;
+  asection *note_secp = NULL;
   int i, len;
 
   /* create the .note section */
@@ -2249,13 +2094,13 @@ sco_id ()
   i_note.type = NT_VERSION;	/* Contains a version string */
 
   p = frag_more (sizeof (i_note.namesz));
-  md_number_to_chars (p, (valueT) i_note.namesz, 4);
+  md_number_to_chars (p, i_note.namesz, 4);
 
   p = frag_more (sizeof (i_note.descsz));
-  md_number_to_chars (p, (valueT) i_note.descsz, 4);
+  md_number_to_chars (p, i_note.descsz, 4);
 
   p = frag_more (sizeof (i_note.type));
-  md_number_to_chars (p, (valueT) i_note.type, 4);
+  md_number_to_chars (p, i_note.type, 4);
 
   p = frag_more (4);
   strcpy (p, "SCO");
@@ -2288,7 +2133,7 @@ sco_id ()
 #endif /* SCO_ELF */
 
 static int
-elf_separate_stab_sections ()
+elf_separate_stab_sections (void)
 {
 #ifdef NEED_ECOFF_DEBUG
   return (!ECOFF_DEBUGGING);
@@ -2298,8 +2143,7 @@ elf_separate_stab_sections ()
 }
 
 static void
-elf_init_stab_section (seg)
-     segT seg;
+elf_init_stab_section (segT seg)
 {
 #ifdef NEED_ECOFF_DEBUG
   if (!ECOFF_DEBUGGING)
